@@ -4,27 +4,27 @@ import (
 	"testing"
 
 	"github.com/lucas-clemente/quic-go"
-	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
-func TestUpstreamDOQ(t *testing.T) {
+func TestUpstreamDoQ(t *testing.T) {
 	// Create a DNS-over-QUIC upstream
-	address := "quic://dns.adguard.com:784"
+	address := "quic://dns.adguard.com"
 	u, err := AddressToUpstream(address, &Options{InsecureSkipVerify: true})
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	uq := u.(*dnsOverQUIC)
-	var sess quic.Session
+	var conn quic.Connection
 
 	// Test that it responds properly
 	for i := 0; i < 10; i++ {
 		checkUpstream(t, u, address)
 
-		if sess == nil {
-			sess = uq.session
+		if conn == nil {
+			conn = uq.conn
 		} else {
-			// This way we test that the session is properly reused
-			assert.True(t, sess == uq.session)
+			// This way we test that the conn is properly reused
+			require.Equal(t, conn, uq.conn)
 		}
 	}
 }
